@@ -10,16 +10,19 @@
 #' @param loc.diff A parameter to control the closeness of the clusters in terms of the difference in their location vectors. Defaults to 1.
 #' @param method A switch indicating whether the mixture to be simulated from is the conditional distribution of the data given the latent variables (default), or simply the marginal distribution of the data.
 #'
-#' @return A data.frame with \code{N} observations (rows) of \code{P} variables (columns). The true values of the parameters which generated these data are also stored.
+#' @return Invisibly returns a data.frame with \code{N} observations (rows) of \code{P} variables (columns). The true values of the parameters which generated these data are also stored.
 #' @export
 #' @importFrom corpcor "is.positive.definite" "make.positive.definite"
+#' @importFrom Rfast "is.symmetric"
 #'
 #' @examples
 #' # Simulate 100 observations from 3 balanced groups with cluster-specific numbers of latent factors
-#' # sim.data <- sim_IMIFA_data(N=100, G=3, P=20, Q=c(2, 2, 5))
-#' # names(attributes(sim.data))
-#' # attr(sim.data, "Labels")
-#' # tmp      <- mcmc_IMIFA(sim.data, method="MIFA", range.G=3, n.iters=5000)
+#' # sim_data <- sim_IMIFA_data(N=100, G=3, P=20, Q=c(2, 2, 5))
+#' # names(attributes(sim_data))
+#' # attr(sim_data, "Labels")
+#'
+#' # Fit a MIFA model to this data
+#' # tmp      <- mcmc_IMIFA(sim_data, method="MIFA", range.G=3, n.iters=5000)
 #' @seealso The function \code{\link{mcmc_IMIFA}} for fitting an IMIFA related model to the simulated data set.
 sim_IMIFA_data <- function(N = 300L, G = 3L, P = 50L, Q = rep(4L, G), pis = rep(1/G, G),
                            nn = NULL, loc.diff = 1L, method = c("conditional", "marginal")) {
@@ -59,14 +62,14 @@ sim_IMIFA_data <- function(N = 300L, G = 3L, P = 50L, Q = rep(4L, G), pis = rep(
            !is.numeric(pis)))             stop(paste0("'pis' must be a numeric vector of length G=", G, " which sums to ", 1))
     nn         <- rep(0,  G)
     while(any(nn < floor(N/(G * G))))  {
-      labs     <- .sim_z.p(N=N, prob.z=pis)
+      labs     <- .sim_z_p(N=N, prob.z=pis)
       nn       <- tabulate(labs, nbins=G)
     }
   }
 
-  simdata      <- matrix(0, nrow=0, ncol=P)
+  simdata      <- base::matrix(0, nrow=0, ncol=P)
   prior.mu     <- as.integer(scale(Gseq, center=TRUE, scale=FALSE))
-  true.mu      <- stats::setNames(vector("list", G), paste0("Group", Gseq))
+  true.mu      <- setNames(vector("list", G), paste0("Group", Gseq))
   true.l       <- true.mu
   true.psi     <- true.mu
   true.cov     <- true.mu
@@ -75,25 +78,25 @@ sim_IMIFA_data <- function(N = 300L, G = 3L, P = 50L, Q = rep(4L, G), pis = rep(
   true.zlab    <- factor(rep(Gseq, nn), labels=Gseq)
   if(method    == "conditional") {
     Q.max      <- max(Q)
-    eta.true   <- .sim_eta.p(Q=Q.max, N=N)
+    eta.true   <- .sim_eta_p(Q=Q.max, N=N)
   }
   for(g in Gseq) {
     Q.g        <- Q[g]
     N.g        <- nn[g]
-    mu.true    <- stats::setNames(.sim_mu.p(P=P, mu.zero=prior.mu[g] * loc.diff, sig.mu.sqrt=1), vnames)
-    l.true     <- .sim_load.p(Q=Q.g, P=P, sigma.l=1)
-    psi.true   <- stats::setNames(stats::runif(P, 0, 1), vnames)
+    mu.true    <- setNames(.sim_mu_p(P=P, mu.zero=prior.mu[g] * loc.diff, sig.mu.sqrt=1), vnames)
+    l.true     <- .sim_load_p(Q=Q.g, P=P, sigma.l=1)
+    psi.true   <- setNames(rgamma(P, 1, 1), vnames)
 
   # Simulate data
-    covmat     <- provideDimnames(diag(psi.true) + switch(method, marginal=tcrossprod(l.true), 0), base=list(vnames, vnames))
-    if(!all(isSymmetric(covmat),
+    covmat     <- provideDimnames(diag(psi.true) + switch(method, marginal=tcrossprod(l.true), 0), base=list(vnames))
+    if(!all(is.symmetric(covmat),
             is.double(covmat)))           stop("Invalid covariance matrix")
-    if(!corpcor::is.positive.definite(covmat)) {
-      covmat   <- corpcor::make.positive.definite(covmat)
+    if(!is.positive.definite(covmat)) {
+      covmat   <- make.positive.definite(covmat)
     }
     sigma      <- if(any(Q.g > 0, method == "conditional")) .chol(covmat) else sqrt(covmat)
     means      <- matrix(mu.true, nrow=N.g, ncol=P, byrow=TRUE) + switch(method, conditional=tcrossprod(eta.true[true.zlab == g, seq_len(Q.g), drop=FALSE], l.true), 0)
-    simdata    <- rbind(simdata, means + matrix(stats::rnorm(N.g * P), nrow=N.g, ncol=P) %*% sigma)
+    simdata    <- rbind(simdata, means + matrix(rnorm(N.g * P), nrow=N.g, ncol=P) %*% sigma)
     dimnames(l.true)   <- list(vnames, if(Q.g > 0) paste0("Factor ", seq_len(Q.g)))
     true.mu[[g]]       <- mu.true
     true.l[[g]]        <- l.true
@@ -132,5 +135,5 @@ sim_IMIFA_data <- function(N = 300L, G = 3L, P = 50L, Q = rep(4L, G), pis = rep(
   attr(simdata,
        "Covariance")   <- true.cov
   class(simdata)       <- c("data.frame")
-  return(simdata)
+    invisible(simdata)
 }
